@@ -455,10 +455,10 @@ void V4LRadioConfiguration::selectRadioDevice()
 
 bool V4LRadioConfiguration::eventFilter(TQObject *o, TQEvent *e)
 {
-    if (e->type() == TQEvent::FocusOut && TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(editRadioDevice)) {
+    if (e->type() == TQEvent::FocusOut && o == editRadioDevice) {
         slotEditRadioDeviceChanged();
     }
-    if (e->type() == TQEvent::MouseButtonDblClick && TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(sliderBalance)) {
+    if (e->type() == TQEvent::MouseButtonDblClick && o == sliderBalance) {
         slotBalanceCenter();
     }
     return false;
